[gimp-gap] applied patch that fixes string typos provided by Christian Kirbach at #648607



commit 1765a6de90a2ce93178581d99e6dbf53972b982b
Author: Wolfgang Hofer <wolfgangh svn gnome org>
Date:   Tue Apr 26 18:37:44 2011 +0200

    applied patch that fixes string typos provided by Christian Kirbach at #648607

 ChangeLog                                  |   15 +++++++++++++++
 gap/gap_morph_tween_dialog.c               |    4 ++--
 gap/gap_player_dialog.c                    |    4 ++--
 gap/gap_story_file.c                       |    6 +++---
 gap/gap_video_index_creator.c              |    2 +-
 gap/gap_wr_opacity.c                       |    2 +-
 vid_common/gap_cme_main.c                  |    2 +-
 vid_enc_avi/gap_enc_avi_main.c             |    4 ++--
 vid_enc_ffmpeg/gap_enc_ffmpeg_main.c       |    4 ++--
 vid_enc_rawframes/gap_enc_rawframes_main.c |    6 +++---
 vid_enc_single/gap_enc_singleframes_main.c |    6 +++---
 11 files changed, 35 insertions(+), 20 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index d744457..ebfd90e 100755
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,18 @@
+2011-04-26 Wolfgang Hofer <hof gimp org>
+
+- applied patch that fixes string typos provided by Christian Kirbach at #648607
+
+ * gap/gap_morph_tween_dialog.c
+ * gap/gap_player_dialog.c
+ * gap/gap_story_file.c
+ * gap/gap_video_index_creator.c
+ * gap/gap_wr_opacity.c
+ * vid_common/gap_cme_main.c
+ * vid_enc_avi/gap_enc_avi_main.c
+ * vid_enc_ffmpeg/gap_enc_ffmpeg_main.c
+ * vid_enc_rawframes/gap_enc_rawframes_main.c
+ * vid_enc_single/gap_enc_singleframes_main.c
+
 2011-02-24 Wolfgang Hofer <hof gimp org>
 
 - added new plug-ins to render an animated water pattern and flame effect, 
diff --git a/gap/gap_player_dialog.c b/gap/gap_player_dialog.c
index 1598abe..cb414e0 100644
--- a/gap/gap_player_dialog.c
+++ b/gap/gap_player_dialog.c
@@ -8073,7 +8073,7 @@ p_create_player_window (GapPlayerMainGlobalParams *gpp)
   gtk_widget_show (play_button);
   gtk_box_pack_start (GTK_BOX (play_n_stop_hbox), play_button, FALSE, TRUE, 0);
   gimp_help_set_help_data (play_button, _("Start playback. "
-                                          "SHIFT: snapshot frames  in a multilayer image at original size "
+                                          "SHIFT: snapshot frames in a multilayer image at original size "
                                           "CTRL: snapshot at preview size "
                                           "ALT: force creation of new snapshot image"), NULL);
   g_signal_connect (G_OBJECT (play_button), "button_press_event",
@@ -8096,7 +8096,7 @@ p_create_player_window (GapPlayerMainGlobalParams *gpp)
   gtk_widget_show (back_button);
   gtk_box_pack_start (GTK_BOX (play_n_stop_hbox), back_button, FALSE, TRUE, 0);
   gimp_help_set_help_data (back_button, _("Start reverse playback. "
-                                          "SHIFT: snapshot frames  in a multilayer image at original size "
+                                          "SHIFT: snapshot frames in a multilayer image at original size "
                                           "CTRL: snapshot at preview size "
                                           "ALT: force creation of new snapshot image"), NULL);
   g_signal_connect (G_OBJECT (back_button), "button_press_event",
diff --git a/gap/gap_story_file.c b/gap/gap_story_file.c
index f6f24ec..69637b6 100644
--- a/gap/gap_story_file.c
+++ b/gap/gap_story_file.c
@@ -3184,7 +3184,7 @@ p_story_parse_line(GapStoryBoard *stb, char *longline
     {
        char *l_errtxt;
 
-       l_errtxt = g_strdup_printf(_("Header not found!\n(line 1 must start with:  %s or %s")
+       l_errtxt = g_strdup_printf(_("Header not found!\n(line 1 must start with:  %s or %s)")
                                  ,  GAP_STBKEY_STB_HEADER
                                  ,  GAP_STBKEY_CLIP_HEADER
                                  );
@@ -3590,7 +3590,7 @@ p_story_parse_line(GapStoryBoard *stb, char *longline
                 {
                    char *l_errtxt;
 
-                   l_errtxt = g_strdup_printf(_("illegal keyword: %s (expected keywords are: width, height, both, none")
+                   l_errtxt = g_strdup_printf(_("illegal keyword: %s (expected keywords are: width, height, both, none)")
                                              , l_from_ptr);
                    p_set_stb_error(stb, l_errtxt);
                    g_free(l_errtxt);
@@ -3617,7 +3617,7 @@ p_story_parse_line(GapStoryBoard *stb, char *longline
             else
             {
                    char *l_errtxt;
-                   l_errtxt = g_strdup_printf(_("illegal keyword: %s (expected keywords are: keep, change")
+                   l_errtxt = g_strdup_printf(_("illegal keyword: %s (expected keywords are: keep, change)")
                                              , l_to_ptr);
                    p_set_stb_warning(stb, l_errtxt);
                    g_free(l_errtxt);
diff --git a/gap/gap_video_index_creator.c b/gap/gap_video_index_creator.c
index 92b01db..82bd01a 100644
--- a/gap/gap_video_index_creator.c
+++ b/gap/gap_video_index_creator.c
@@ -932,7 +932,7 @@ p_vindex_dialog(VindexValues *val_ptr)
                                               "and no critical timecode steps are detected in the probereads so far.\n"
                                               "\nWARNING: positioning via native seek may not work exact in case critical "
                                               "timecode steps were not detected in the probereads.")
-                                         , N_("Create video index. Requires unconditional full scan of all frames."
+                                         , N_("Create video index. Requires unconditional full scan of all frames. "
                                               "Native seek is enabled only in case all timecodes are OK.")
                                          };
 
diff --git a/gap/gap_wr_opacity.c b/gap/gap_wr_opacity.c
index ccef9c5..69c105e 100644
--- a/gap/gap_wr_opacity.c
+++ b/gap/gap_wr_opacity.c
@@ -354,7 +354,7 @@ p_opa_dialog(void)
 
   ii++; gap_arr_arg_init(&argv[ii], GAP_ARR_WGT_DEFAULT_BUTTON);
   argv[ii].label_txt = _("Default");
-  argv[ii].help_txt  = _("Reset all Parameters to Default Values");
+  argv[ii].help_txt  = _("Reset all parameters to default values");
 
   if(TRUE == gap_arr_ok_cancel_dialog(_("Set Layer Opacity"),
                             _("Settings :"),
diff --git a/vid_common/gap_cme_main.c b/vid_common/gap_cme_main.c
index 6f7123e..8f99ff1 100644
--- a/vid_common/gap_cme_main.c
+++ b/vid_common/gap_cme_main.c
@@ -151,7 +151,7 @@ query ()
                          " and passed to the selected videoencoder plug-in as temporary file."
                          " (or direct if format and samplerate already matches the desired target samplerate)."
                          " The videoformat is defined with vid_enc_plugin parameter. The specified plugin "
-                         " is called with the Parameters specified in the dialog. for noninteractive calls"
+                         " is called with the parameters specified in the dialog. for noninteractive calls"
                          " default values will be used. (you may call the desired plugin directly if you"
                          " want to specify non-interacive parameters"),
                          "Wolfgang Hofer (hof gimp org)",
diff --git a/vid_enc_avi/gap_enc_avi_main.c b/vid_enc_avi/gap_enc_avi_main.c
index 256009d..96cc0ec 100644
--- a/vid_enc_avi/gap_enc_avi_main.c
+++ b/vid_enc_avi/gap_enc_avi_main.c
@@ -224,7 +224,7 @@ query ()
 
 
   gimp_install_procedure(GAP_PLUGIN_NAME_AVI_PARAMS,
-                         _("Set Parameters for GAP avi video encoder Plugins"),
+                         _("Set parameters for GAP avi video encoder Plugins"),
                          _("This plugin sets avi specific video encoding parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
@@ -238,7 +238,7 @@ query ()
 
   l_ecp_key = g_strdup_printf("%s%s", GAP_QUERY_PREFIX_VIDEO_ENCODERS, GAP_PLUGIN_NAME_AVI_ENCODE);
   gimp_install_procedure(l_ecp_key,
-                         _("Get GUI Parameters for GAP avi video encoder"),
+                         _("Get GUI parameters for GAP avi video encoder"),
                          _("This plugin returns avi encoder specific parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
diff --git a/vid_enc_ffmpeg/gap_enc_ffmpeg_main.c b/vid_enc_ffmpeg/gap_enc_ffmpeg_main.c
index 5fe8693..f00172b 100644
--- a/vid_enc_ffmpeg/gap_enc_ffmpeg_main.c
+++ b/vid_enc_ffmpeg/gap_enc_ffmpeg_main.c
@@ -491,7 +491,7 @@ query ()
 
 
   gimp_install_procedure(GAP_PLUGIN_NAME_FFMPEG_PARAMS,
-                         _("Set Parameters for GAP ffmpeg video encoder Plugin"),
+                         _("Set parameters for GAP ffmpeg video encoder Plugin"),
                          _("This plugin sets ffmpeg specific video encoding parameters."
                            " Non-interactive callers must provide a parameterfile,"
                            " Interactive calls provide a dialog window to specify and optionally save the parameters."),
@@ -507,7 +507,7 @@ query ()
 
   l_ecp_key = g_strdup_printf("%s%s", GAP_QUERY_PREFIX_VIDEO_ENCODERS, GAP_PLUGIN_NAME_FFMPEG_ENCODE);
   gimp_install_procedure(l_ecp_key,
-                         _("Get GUI Parameters for GAP ffmpeg video encoder"),
+                         _("Get GUI parameters for GAP ffmpeg video encoder"),
                          _("This plugin returns ffmpeg encoder specific parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
diff --git a/vid_enc_rawframes/gap_enc_rawframes_main.c b/vid_enc_rawframes/gap_enc_rawframes_main.c
index 2742ccc..d259539 100644
--- a/vid_enc_rawframes/gap_enc_rawframes_main.c
+++ b/vid_enc_rawframes/gap_enc_rawframes_main.c
@@ -211,7 +211,7 @@ query ()
 
 
   gimp_install_procedure(GAP_PLUGIN_NAME_RAWFRAMES_PARAMS,
-                         _("Set Parameters for GAP rawframes video encoder Plugins"),
+                         _("Set parameters for GAP rawframes video encoder Plugins"),
                          _("This plugin sets rawframes specific video encoding parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
@@ -225,7 +225,7 @@ query ()
 
   l_ecp_key = g_strdup_printf("%s%s", GAP_QUERY_PREFIX_VIDEO_ENCODERS, GAP_PLUGIN_NAME_rawframeS_ENCODE);
   gimp_install_procedure(l_ecp_key,
-                         _("Get GUI Parameters for GAP rawframes video encoder"),
+                         _("Get GUI parameters for GAP rawframes video encoder"),
                          _("This plugin returns rawframes encoder specific parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
@@ -524,7 +524,7 @@ p_rawframe_init_default_params(GapGveRawValues *epp)
 gint
 p_rawframe_encode_dialog(GapGveRawGlobalParams *gpp)
 {
-  gap_arr_msg_popup(GIMP_RUN_INTERACTIVE, _("the rawframe Encoder has no encoder specific Parameters"));
+  gap_arr_msg_popup(GIMP_RUN_INTERACTIVE, _("the rawframe encoder has no encoder specific parameters"));
   return 0;
 }  /* end p_rawframe_encode_dialog */
 
diff --git a/vid_enc_single/gap_enc_singleframes_main.c b/vid_enc_single/gap_enc_singleframes_main.c
index addaab5..84e16e2 100644
--- a/vid_enc_single/gap_enc_singleframes_main.c
+++ b/vid_enc_single/gap_enc_singleframes_main.c
@@ -202,7 +202,7 @@ query ()
 
 
   gimp_install_procedure(GAP_PLUGIN_NAME_SINGLEFRAMES_PARAMS,
-                         _("Set Parameters for GAP singleframes video encoder Plugins"),
+                         _("Set parameters for GAP singleframes video encoder Plugins"),
                          _("This plugin sets singleframes specific video encoding parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
@@ -216,7 +216,7 @@ query ()
 
   l_ecp_key = g_strdup_printf("%s%s", GAP_QUERY_PREFIX_VIDEO_ENCODERS, GAP_PLUGIN_NAME_SINGLEFRAMES_ENCODE);
   gimp_install_procedure(l_ecp_key,
-                         _("Get GUI Parameters for GAP singleframes video encoder"),
+                         _("Get GUI parameters for GAP singleframes video encoder"),
                          _("This plugin returns singleframes encoder specific parameters."),
                          "Wolfgang Hofer (hof gimp org)",
                          "Wolfgang Hofer",
@@ -509,7 +509,7 @@ p_singleframe_init_default_params(GapGveSingleValues *epp)
 gint
 p_singleframe_encode_dialog(GapGveSingleGlobalParams *gpp)
 {
-  gap_arr_msg_popup(GIMP_RUN_INTERACTIVE, _("the Singleframe Encoder has no encoder specific Parameters"));
+  gap_arr_msg_popup(GIMP_RUN_INTERACTIVE, _("the Singleframe Encoder has no encoder specific parameters"));
   return 0;
 }  /* end p_singleframe_encode_dialog */
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gap/gap_morph_tween_dialog.c b/gap/gap_morph_tween_dialog.c
index 4cd809a..5d92aca 100644
--- a/gap/gap_morph_tween_dialog.c
+++ b/gap/gap_morph_tween_dialog.c
@@ -1224,7 +1224,7 @@ gap_morph_frame_tweens_dialog(GapAnimInfo *ainfo_ptr, GapMorphGlobalParams *mgpp
                                 mgpp->master_tween_steps, 0, 100, 1.0, 10.0, 0,
                                 TRUE, 0, 0,
                                 _("Number of tweens to be inserted between 2 frames. "
-                                  "Value 0 renderes missing frames (via morping or fade)"
+                                  "Value 0 renderes missing frames (via morphing or fade) "
                                   "but does not create tweens where the "
                                   "next frame number is equal to the current processed frame number +1"),
                                 NULL);
@@ -1245,7 +1245,7 @@ gap_morph_frame_tweens_dialog(GapAnimInfo *ainfo_ptr, GapMorphGlobalParams *mgpp
 //     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), mgpp->create_tweens_in_subdir);
 //     gimp_help_set_help_data(checkbutton,
 //                          _("ON: copy processed frames to a subdirectory "
 //                            "and create tween frames in this subdirectory via morping."
 //                            "OFF: Render missing frames via moprhing. ")
 //                          , NULL);
 
@@ -1245,7 +1245,7 @@ gap_morph_frame_tweens_dialog(GapAnimInfo *ainfo_ptr, GapMorphGlobalParams *mgpp
 //     gimp_help_set_help_data(checkbutton,
 //                          _("ON: copy processed frames to a subdirectory "
-//                            "and create tween frames in this subdirectory via morping."
+//                            "and create tween frames in this subdirectory via morphing."
 //                            "OFF: Render missing frames via moprhing. ")
 //                          , NULL);